@@ -3,6 +3,7 @@ from ._basefakesocket import BaseFakeSocket
 from .commands_mixins.bitmap_mixin import BitmapCommandsMixin
 from .commands_mixins.connection_mixin import ConnectionCommandsMixin
 from .commands_mixins.generic_mixin import GenericCommandsMixin
+from .commands_mixins.geo_mixin import GeoCommandsMixin
 from .commands_mixins.hash_mixin import HashCommandsMixin
 from .commands_mixins.list_mixin import ListCommandsMixin
 from .commands_mixins.pubsub_mixin import PubSubCommandsMixin
@@ -31,6 +32,7 @@ class FakeSocket(
     SortedSetCommandsMixin,
     StreamsCommandsMixin,
     JSONCommandsMixin,
+    GeoCommandsMixin,
 ):
 
     def __init__(self, server):
