@@ -1,6 +1,8 @@
 from fakeredis import _msgs as msgs
 from fakeredis._commands import command, DbIndex
-from fakeredis._helpers import SimpleError, OK, PONG
+from fakeredis._helpers import SimpleError, OK, SimpleString
+
+PONG = SimpleString(b'PONG')
 
 
 class ConnectionCommandsMixin:
@@ -13,8 +15,8 @@ class ConnectionCommandsMixin:
 
     @command((), (bytes,))
     def ping(self, *args):
-        msg = msgs.WRONG_ARGS_MSG7 if self.version >= 7 else msgs.WRONG_ARGS_MSG6.format('ping')
         if len(args) > 1:
+            msg = msgs.WRONG_ARGS_MSG7 if self.version >= 7 else msgs.WRONG_ARGS_MSG6.format('ping')
             raise SimpleError(msg)
         if self._pubsub:
             return [b'pong', args[0] if args else b'']
